pub struct InfCube;Expand description
The infinity cube {0, inf}^n, whose per-variable basis is (1, X).
The vertex inf selects a multilinear’s leading coefficient in that variable.
So the coefficient indexed by a vertex v belongs to the monomial
prod_{i : v_i = inf} X_iTrait Implementations
Sourceimpl Hypercube for InfCube
impl Hypercube for InfCube
Sourcefn basis<F: FieldOps>(coord: &F) -> [F; 2]
fn basis<F: FieldOps>(coord: &F) -> [F; 2]
Evaluates the basis of one variable at a coordinate. Read more
Sourcefn expand_var<F: FieldOps>(value: &F, coord: &F) -> [F; 2]
fn expand_var<F: FieldOps>(value: &F, coord: &F) -> [F; 2]
Scales the basis of one variable by a value. Read more
Sourcefn contract_var<F: FieldOps>(_lo: &mut F, _hi: &F)
fn contract_var<F: FieldOps>(_lo: &mut F, _hi: &F)
Strips one variable’s basis factor from the two halves of an expansion. Read more
Sourcefn eq_one_var<F: FieldOps>(x: F, y: F) -> F
fn eq_one_var<F: FieldOps>(x: F, y: F) -> F
Evaluates the equality indicator of one variable. Read more