pub struct OneCube;Expand description
The Boolean cube {0, 1}^n, whose per-variable basis is (1 - X, X).
That basis is the pair of Lagrange polynomials on the two vertices 0 and 1.
So the coefficient indexed by a vertex is the multilinear’s evaluation at that vertex.