pub fn eq_ind_partial_eval<Cube: Hypercube, P: PackedField>(
point: &[P::Scalar],
) -> FieldBuffer<P>Expand description
Computes the partial evaluation of the equality indicator polynomial.
For the point r = (r_0, ..., r_{n-1}) the result holds the 2^n coefficients
b(r_0) (x) ... (x) b(r_{n-1})which are the coefficients of the equality indicator eq(X_0, ..., X_{n-1}, r) over the cube.